@@ -159,7 +159,7 @@ set_check = function(x){
 #' @param .up An integer greater or equal to 0.
 #'
 #' @details
-#' The function \code{set_up} does not set the argument \code{up} globally.
+#' The function \code{set_up} does not set the argument \code{up} globally, but only for all calls to \code{check_arg} and \code{check_value} within the same function.
 #'
 #'
 #' @examples
@@ -179,7 +179,7 @@ set_check = function(x){
 #'   check_arg(x, y, "numeric scalar mbt")
 #'
 #'   # Identical to calling
-#'   # check_arg(x, y, "numeric scalar mbt", .call_up = 1)
+#'   # check_arg(x, y, "numeric scalar mbt", .up = 1)
 #'
 #'   if(sum) return(x + y)
 #'   return(x - y)
@@ -483,6 +483,8 @@ enumerate_items = function (x, type, verb = FALSE, s = FALSE, past = FALSE, or =
   # function that enumerates items and add verbs
   # in argument type, you can have a mix of the different arguments, all separated with a "."
 
+  if(length(x) == 0) return("");
+
   if(!missing(type)){
     args = strsplit(type, "\\.")[[1]]
     s = "s" %in% args
@@ -538,17 +540,19 @@ enumerate_items = function (x, type, verb = FALSE, s = FALSE, past = FALSE, or =
   # Ensuring it's not too long
   if(n > nmax){
 
+    nmax = nmax - 1
+
     other = trimws(other)
     if(nchar(other) > 0){
-      other = paste0(other, " ", n - 5, " others")
+      other = paste0(other, " ", n - nmax, " others")
     } else {
-      other = paste0(n - 5, " others")
+      other = paste0(n - nmax, " others")
     }
 
     if(quote){
-      x = c(paste0("'", x[1:5], "'"), other)
+      x = c(paste0("'", x[1:nmax], "'"), other)
     } else {
-      x = c(x[1:5], other)
+      x = c(x[1:nmax], other)
     }
 
     n = length(x)
@@ -1069,6 +1073,8 @@ sfill = function(x = "", n = NULL, symbol = " ", right = FALSE, anchor){
   check_arg(right, "logical scalar")
   check_arg(anchor, "character scalar")
 
+  x[is.na(x)] = "NA"
+
   if(nchar(symbol) != 1) stop("Argument 'symbol' must be a single character (currenlty it is of length ", nchar(symbol), ").")
 
   IS_ANCHOR = FALSE
